__version__ = "0.0.5"
__git_commiter_name__ = "Guy Rozendorn"
__git_commiter_email__ = "guy@rzn.co.il"
__git_branch__ = '(detached from v0.0.5)'
__git_remote_tracking_branch__ = '(No remote tracking)'
__git_remote_url__ = '(Not remote tracking)'
__git_head_hash__ = 'd339b2ac7935c87f79ed3afe654d84014898575d'
__git_head_subject__ = 'buildout.cfg: changed isolated python version to v2.7.5.5'
__git_head_message__ = ''
__git_dirty_diff__ = ''